@@ -18,6 +18,23 @@ else
     MURANO_BIN_DIR=$(get_python_exec_prefix)
 fi
 
+MURANO_AUTH_CACHE_DIR=${MURANO_AUTH_CACHE_DIR:-/var/cache/murano}
+
+# Toggle for deploying Murano-API under under a wsgi server
+MURANO_USE_UWSGI=${MURANO_USE_UWSGI:-True}
+
+MURANO_UWSGI=$MURANO_BIN_DIR/murano-wsgi-api
+MURANO_UWSGI_CONF=$MURANO_CONF_DIR/murano-api-uwsgi.ini
+
+if [[ "$MURANO_USE_UWSGI" == "True" ]]; then
+    MURANO_API_URL="$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST/application-catalog"
+else
+    MURANO_API_URL="$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST:$MURANO_SERVICE_PORT"
+fi
+
+HORIZON_URL="http://${KEYSTONE_SERVICE_HOST}/dashboard"
+
+DASHBOARD_FUNCTIONAL_CONFIG_DIR=$MURANO_DASHBOARD_DIR/muranodashboard/tests/functional/config
 
 # create_murano_accounts() - Set up common required murano accounts
 #
@@ -29,14 +46,14 @@ function create_murano_accounts() {
         return
     fi
 
-    create_service_user "murano"
+    create_service_user "murano" "admin"
 
     get_or_create_service "murano" "application-catalog" "Application Catalog Service"
     get_or_create_endpoint "application-catalog" \
         "$REGION_NAME" \
-        "$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST:$MURANO_SERVICE_PORT" \
-        "$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST:$MURANO_SERVICE_PORT" \
-        "$MURANO_SERVICE_PROTOCOL://$MURANO_SERVICE_HOST:$MURANO_SERVICE_PORT"
+        "$MURANO_API_URL" \
+        "$MURANO_API_URL" \
+        "$MURANO_API_URL"
 
     if is_service_enabled murano-cfapi; then
     get_or_create_service "murano-cfapi" "service-broker" "Murano CloudFoundry Service Broker"
@@ -153,20 +170,16 @@ function configure_murano {
     mkdir_chown_stack "$MURANO_CONF_DIR"
 
     # Generate Murano configuration file and configure common parameters.
-    oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace murano \
-                          --namespace oslo.db \
-                          --namespace oslo.messaging \
-                          > $MURANO_CONF_FILE
+    oslo-config-generator --config-file $MURANO_DIR/etc/oslo-config-generator/murano.conf --output-file $MURANO_CONF_FILE
+
     cp $MURANO_DIR/etc/murano/murano-paste.ini $MURANO_CONF_DIR
-    cp $MURANO_DIR/etc/murano/policy.json $MURANO_POLICY_FILE
 
     cleanup_murano
 
     iniset $MURANO_CONF_FILE DEFAULT debug $MURANO_DEBUG
     iniset $MURANO_CONF_FILE DEFAULT use_syslog $SYSLOG
     # Format logging
-    if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ]; then
+    if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ] && [ "$MURANO_USE_UWSGI" == "False" ] ; then
         setup_colorized_logging $MURANO_CONF_FILE DEFAULT
     else
         # Show user_name and project_name instead of user_id and project_id
@@ -176,7 +189,7 @@ function configure_murano {
     iniset $MURANO_CONF_FILE DEFAULT home_region $REGION_NAME
 
     # Murano Policy Enforcement Configuration
-    if [[ -n "$MURANO_ENABLE_MODEL_POLICY_ENFORCEMENT" ]]; then
+    if [[ "$MURANO_ENABLE_MODEL_POLICY_ENFORCEMENT" == "True" ]]; then
         iniset $MURANO_CONF_FILE engine enable_model_policy_enforcer $MURANO_ENABLE_MODEL_POLICY_ENFORCEMENT
     fi
 
@@ -184,14 +197,11 @@ function configure_murano {
     #-------------------------
 
     # Setup keystone_authtoken section
-    iniset $MURANO_CONF_FILE keystone_authtoken auth_uri "http://${KEYSTONE_AUTH_HOST}:5000"
-    iniset $MURANO_CONF_FILE keystone_authtoken auth_host $KEYSTONE_AUTH_HOST
-    iniset $MURANO_CONF_FILE keystone_authtoken auth_port $KEYSTONE_AUTH_PORT
-    iniset $MURANO_CONF_FILE keystone_authtoken auth_protocol $KEYSTONE_AUTH_PROTOCOL
-    iniset $MURANO_CONF_FILE keystone_authtoken cafile $KEYSTONE_SSL_CA
-    iniset $MURANO_CONF_FILE keystone_authtoken admin_tenant_name $SERVICE_TENANT_NAME
-    iniset $MURANO_CONF_FILE keystone_authtoken admin_user $MURANO_ADMIN_USER
-    iniset $MURANO_CONF_FILE keystone_authtoken admin_password $SERVICE_PASSWORD
+    configure_auth_token_middleware $MURANO_CONF_FILE $MURANO_ADMIN_USER $MURANO_AUTH_CACHE_DIR
+
+    # Setup murano_auth section
+    configure_auth_token_middleware $MURANO_CONF_FILE $MURANO_ADMIN_USER $MURANO_AUTH_CACHE_DIR murano_auth
+    iniset $MURANO_CONF_FILE murano_auth www_authenticate_uri  $KEYSTONE_AUTH_URI
 
     configure_murano_rpc_backend
 
@@ -202,10 +212,10 @@ function configure_murano {
     iniset $MURANO_CONF_FILE database connection `database_connection_url murano`
 
     # Configure keystone auth url
-    iniset $MURANO_CONF_FILE keystone auth_url "http://${KEYSTONE_AUTH_HOST}:5000"
+    iniset $MURANO_CONF_FILE keystone auth_url $KEYSTONE_SERVICE_URI
 
     # Configure Murano API URL
-    iniset $MURANO_CONF_FILE murano url "http://127.0.0.1:8082"
+    iniset $MURANO_CONF_FILE murano url "$MURANO_API_URL"
 
     # Configure the number of api workers
     if [[ -n "$MURANO_API_WORKERS" ]]; then
@@ -219,6 +229,11 @@ function configure_murano {
     if is_murano_backend_glare; then
         configure_murano_glare_backend
     fi
+
+    if [ "$MURANO_USE_UWSGI" == "True" ]; then
+        write_uwsgi_config "$MURANO_UWSGI_CONF" "$MURANO_UWSGI" "/application-catalog"
+    fi
+
 }
 
 # set the murano packages service backend
@@ -234,10 +249,8 @@ function set_packages_service_backend() {
 function configure_murano_cfapi {
 
     # Generate Murano configuration file and configure common parameters.
-    oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace murano.cfapi \
-                          --namespace oslo.db \
-                          > $MURANO_CFAPI_CONF_FILE
+    oslo-config-generator --config-file $MURANO_DIR/etc/oslo-config-generator/murano-cfapi.conf --output-file $MURANO_CFAPI_CONF_FILE
+
     cp $MURANO_DIR/etc/murano/murano-cfapi-paste.ini $MURANO_CONF_DIR
 
     configure_service_broker
@@ -265,8 +278,8 @@ function install_murano_apps() {
                 murano --os-username $OS_USERNAME \
                        --os-password $OS_PASSWORD \
                        --os-tenant-name $OS_PROJECT_NAME \
-                       --os-auth-url http://$KEYSTONE_AUTH_HOST:5000 \
-                       --murano-url http://127.0.0.1:8082 \
+                       --os-auth-url $KEYSTONE_SERVICE_URI \
+                       --murano-url $MURANO_API_URL \
                        --glare-url $GLANCE_SERVICE_PROTOCOL://$GLANCE_GLARE_HOSTPORT \
                        --murano-packages-service $MURANO_PACKAGES_SERVICE \
                        package-import \
@@ -290,29 +303,27 @@ function configure_service_broker {
     iniset $MURANO_CFAPI_CONF_FILE cfapi tenant "$MURANO_CFAPI_DEFAULT_TENANT"
     iniset $MURANO_CFAPI_CONF_FILE cfapi bind_host "$MURANO_SERVICE_HOST"
     iniset $MURANO_CFAPI_CONF_FILE cfapi bind_port "$MURANO_CFAPI_SERVICE_PORT"
-    iniset $MURANO_CFAPI_CONF_FILE cfapi auth_url "http://${KEYSTONE_AUTH_HOST}:5000"
+    iniset $MURANO_CFAPI_CONF_FILE cfapi auth_url "$KEYSTONE_SERVICE_URI"
 
     # configure the database.
     iniset $MURANO_CFAPI_CONF_FILE database connection `database_connection_url murano_cfapi`
 
     # Setup keystone_authtoken section
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken auth_uri "http://${KEYSTONE_AUTH_HOST}:5000"
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken auth_host $KEYSTONE_AUTH_HOST
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken auth_port $KEYSTONE_AUTH_PORT
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken auth_protocol $KEYSTONE_AUTH_PROTOCOL
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken cafile $KEYSTONE_SSL_CA
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken admin_tenant_name $SERVICE_TENANT_NAME
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken admin_user $MURANO_ADMIN_USER
-    iniset $MURANO_CFAPI_CONF_FILE keystone_authtoken admin_password $SERVICE_PASSWORD
+    configure_auth_token_middleware $MURANO_CFAPI_CONF_FILE $MURANO_ADMIN_USER $MURANO_AUTH_CACHE_DIR
 
 }
 
-function prepare_core_library() {
-    cd $MURANO_DIR/meta/io.murano && zip -r io.murano.zip .
+function prepare_core_apps() {
+    cd $MURANO_DIR/meta
+    for i in */
+        do pushd ./"$i"
+        zip -r ../"${i%/}.zip" *
+        popd
+    done
 }
 
-function remove_core_library_zip() {
-    rm -f $MURANO_DIR/meta/io.murano/io.murano.zip
+function remove_core_apps_zip() {
+    rm -f $MURANO_DIR/meta/*.zip
 }
 
 # init_murano() - Initialize databases, etc.
@@ -323,8 +334,18 @@ function init_murano() {
     recreate_database murano utf8
 
     $MURANO_BIN_DIR/murano-db-manage --config-file $MURANO_CONF_FILE upgrade
+
+    create_murano_cache_dir
+
 }
 
+# create_murano_cache_dir() - Part of the init_murano() process
+function create_murano_cache_dir {
+    # Create cache dirs
+    sudo install -d -o $STACK_USER $MURANO_AUTH_CACHE_DIR
+}
+
+
 # init_murano_cfapi() - Initialize databases, etc.
 function init_murano_cfapi() {
 
@@ -335,23 +356,24 @@ function init_murano_cfapi() {
 }
 
 function setup_core_library() {
-    prepare_core_library
+    prepare_core_apps
 
     set_packages_service_backend
 
     murano --os-username admin \
            --os-password $ADMIN_PASSWORD \
            --os-tenant-name admin \
-           --os-auth-url http://$KEYSTONE_AUTH_HOST:5000 \
+           --os-auth-url $KEYSTONE_SERVICE_URI \
            --os-region-name $REGION_NAME \
-           --murano-url http://127.0.0.1:8082 \
+           --murano-url $MURANO_API_URL \
            --glare-url $GLANCE_SERVICE_PROTOCOL://$GLANCE_GLARE_HOSTPORT \
            --murano-packages-service $MURANO_PACKAGES_SERVICE \
-           package-import $MURANO_DIR/meta/io.murano/io.murano.zip \
+           package-import $MURANO_DIR/meta/*.zip \
            --is-public
-    remove_core_library_zip
 
+    remove_core_apps_zip
 }
+
 # install_murano() - Collect source and prepare
 function install_murano() {
     install_murano_pythonclient
@@ -363,6 +385,7 @@ function install_murano() {
     if is_murano_backend_glare; then
         install_murano_artifact_plugin
     fi
+
 }
 
 function install_murano_pythonclient() {
@@ -380,29 +403,38 @@ function install_murano_pythonclient() {
 
 # start_murano() - Start running processes, including screen
 function start_murano() {
-    screen_it murano-api "cd $MURANO_DIR && $MURANO_BIN_DIR/murano-api --config-file $MURANO_CONF_DIR/murano.conf"
-    screen_it murano-engine "cd $MURANO_DIR && $MURANO_BIN_DIR/murano-engine --config-file $MURANO_CONF_DIR/murano.conf"
+    if [ "$MURANO_USE_UWSGI" == "True" ]; then
+        run_process murano-api "$MURANO_BIN_DIR/uwsgi --ini $MURANO_UWSGI_CONF"
+    else
+        run_process murano-api "$MURANO_BIN_DIR/murano-api --config-file $MURANO_CONF_DIR/murano.conf"
+    fi
+    run_process murano-engine "$MURANO_BIN_DIR/murano-engine --config-file $MURANO_CONF_DIR/murano.conf"
 }
 
 
 # stop_murano() - Stop running processes
 function stop_murano() {
     # Kill the Murano screen windows
-    screen -S $SCREEN_NAME -p murano-api -X kill
-    screen -S $SCREEN_NAME -p murano-engine -X kill
+    if [ "$MURANO_USE_UWSGI" == "True" ]; then
+        disable_apache_site murano-api
+        restart_apache_server
+    else
+        stop_process murano-api
+    fi
+    stop_process murano-engine
 }
 
 
 # start_service_broker() - start murano CF service broker
 function start_service_broker() {
-    screen_it murano-cfapi "cd $MURANO_DIR && $MURANO_BIN_DIR/murano-cfapi --config-file $MURANO_CONF_DIR/murano-cfapi.conf"
+    run_process murano-cfapi "$MURANO_BIN_DIR/murano-cfapi --config-file $MURANO_CONF_DIR/murano-cfapi.conf"
 }
 
 
 # stop_service_broker() - stop murano CF service broker
 function stop_service_broker() {
     # Kill the Murano screen windows
-    screen -S $SCREEN_NAME -p murano-cfapi -X kill
+    stop_process murano-cfapi
 }
 
 
@@ -410,6 +442,11 @@ function cleanup_murano() {
 
     # Cleanup keystone signing dir
     sudo rm -rf $MURANO_KEYSTONE_SIGNING_DIR
+
+    if [[ "$MURANO_USE_UWSGI" == "True" ]]; then
+        remove_uwsgi_config "$MURANO_UWSGI_CONF" "$MURANO_UWSGI"
+    fi
+
 }
 
 function configure_murano_tempest_plugin() {
@@ -419,10 +456,6 @@ function configure_murano_tempest_plugin() {
         echo_summary "Configuring Murano Tempest plugin"
         # Set murano service availability flag
         iniset $TEMPEST_CONFIG service_available murano "True"
-        # Running tempest in isolation will using tempest user.
-        if sudo id -u tempest >/dev/null 2>&1; then
-            sudo chown -R tempest:stack $MURANO_DIR/murano_tempest_tests
-        fi
         if is_service_enabled murano-cfapi; then
             # Enable Service Broker tests if cfapi enabled and set murano-cfapi service availability flag
             iniset $TEMPEST_CONFIG service_available murano_cfapi "True"
@@ -437,6 +470,15 @@ function configure_murano_tempest_plugin() {
         if is_murano_backend_glare; then
             iniset $TEMPEST_CONFIG application_catalog glare_backend "True"
         fi
+        if [[ "$TEMPEST_MURANO_SCENARIO_TESTS_ENABLED" == "True" ]]; then
+            if is_service_enabled cinder; then
+                iniset $TEMPEST_CONFIG application_catalog cinder_volume_tests "True"
+            fi
+            if [[ "$TEMPEST_MURANO_DEPLOYMENT_TESTS_ENABLED" == "True" ]]; then
+                iniset $TEMPEST_CONFIG application_catalog deployment_tests "True"
+                iniset $TEMPEST_CONFIG application_catalog linux_image "$CLOUD_IMAGE_NAME"
+            fi
+        fi
     fi
 }
 
@@ -454,7 +496,7 @@ function configure_murano_tempest_plugin() {
 # - configure_murano_dashboard
 # - cleanup_murano_dashboard
 
-source $TOP_DIR/lib/horizon
+. $TOP_DIR/lib/horizon
 
 # Defaults
 # --------
@@ -481,10 +523,26 @@ MURANO_REPOSITORY_URL=${MURANO_REPOSITORY_URL:-'http://apps.openstack.org/api/v1
 function configure_murano_dashboard() {
     configure_local_settings_py
 
+    configure_dashboard_functional_config
+
     restart_apache_server
 }
 
 
+function configure_dashboard_functional_config() {
+    cp $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf.sample $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf
+    sed -e "s%\(^\s*horizon_url\s*=\).*$%\1 $HORIZON_URL%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s%\(^\s*murano_url\s*=\).*$%\1 $MURANO_API_URL%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*user\s*=\).*$/\1 $OS_USERNAME/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*password\s*=\).*$/\1 $OS_PASSWORD/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s/\(^\s*tenant\s*=\).*$/\1 $OS_PROJECT_NAME/" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+    sed -e "s%\(^\s*keystone_url\s*=\).*$%\1 $KEYSTONE_SERVICE_URI/v3%" -i "$DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf"
+
+    echo_summary "Show the DASHBOARD_FUNCTIONAL_CONFIG"
+    cat $DASHBOARD_FUNCTIONAL_CONFIG_DIR/config.conf
+}
+
+
 function configure_local_settings_py() {
     local horizon_config_part=$(mktemp)
 
@@ -516,7 +574,6 @@ function configure_local_settings_py() {
     sed -e "s%\(^\s*MURANO_REPO_URL\s*=\).*$%\1 '$MURANO_REPOSITORY_URL'%" -i $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
     sed -e "s%\(^\s*'NAME':\).*$%\1 os.path.join('$MURANO_DASHBOARD_DIR', 'openstack-dashboard.sqlite')%" -i $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
     echo -e $"\nMETADATA_CACHE_DIR = '$MURANO_DASHBOARD_CACHE_DIR'" | sudo tee -a $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
-    echo -e $"\nGLARE_API_URL = '$GLANCE_SERVICE_PROTOCOL://$GLANCE_GLARE_HOSTPORT'" | sudo tee -a $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
 
 }
 
@@ -527,13 +584,13 @@ function init_murano_dashboard() {
 
     local horizon_manage_py="$HORIZON_DIR/manage.py"
 
-    python "$horizon_manage_py" collectstatic --noinput
-    python "$horizon_manage_py" compress --force
-    python "$horizon_manage_py" migrate --noinput
+    $PYTHON "$horizon_manage_py" collectstatic --noinput
+    $PYTHON "$horizon_manage_py" compress --force
+    $PYTHON "$horizon_manage_py" migrate --noinput
 
     # Compile message for murano-dashboard
     cd $MURANO_DASHBOARD_DIR/muranodashboard
-    python "$horizon_manage_py" compilemessages
+    $PYTHON "$horizon_manage_py" compilemessages
 
     restart_apache_server
 }
@@ -554,9 +611,12 @@ function install_murano_dashboard() {
 function cleanup_murano_dashboard() {
     echo_summary "Cleanup Murano Dashboard"
 
-    rm $HORIZON_DIR/openstack_dashboard/local/enabled/_50_murano.py
+    # remove all the pannels we've installed, also any pyc/pyo files
+    for i in $(find $MURANO_DASHBOARD_DIR/muranodashboard/local/enabled -iname '_[0-9]*.py' -printf '%f\n'); do
+        rm -rf $HORIZON_DIR/openstack_dashboard/local/enabled/${i%.*}.*
+    done
 
-    rm $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.py
+    rm $HORIZON_DIR/openstack_dashboard/local/local_settings.d/_50_murano.*
 
     rm $HORIZON_DIR/openstack_dashboard/conf/murano_policy.json
 }
@@ -594,14 +654,16 @@ if is_service_enabled murano; then
             init_murano_cfapi
             start_service_broker
         fi
-        setup_core_library
-        configure_murano_tempest_plugin
 
         # Give Murano some time to Start
         sleep 3
 
+        setup_core_library
+
         # Install Murano apps, if needed
         install_murano_apps
+    elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
+        configure_murano_tempest_plugin
     fi
 
     if [[ "$1" == "unstack" ]]; then
