@@ -14,17 +14,17 @@
 
 from oslo_log import log as logging
 from sqlalchemy import desc
+from sqlalchemy.orm import load_only
 from webob import exc
 
 from murano.api.v1 import request_statistics
 from murano.common.helpers import token_sanitizer
-from murano.common.i18n import _LE
 from murano.common import policy
 from murano.common import utils
 from murano.common import wsgi
 from murano.db import models
 from murano.db import session as db_session
-from murano.utils import verify_env
+from murano.utils import check_env
 
 LOG = logging.getLogger(__name__)
 
@@ -33,18 +33,41 @@ API_NAME = 'Deployments'
 
 class Controller(object):
     @request_statistics.stats_count(API_NAME, 'Index')
-    @verify_env
-    def index(self, request, environment_id):
-        target = {"environment_id": environment_id}
-        policy.check("list_deployments", request.context, target)
+    def index(self, request, environment_id=None):
+        all_environments = environment_id is None
+        LOG.debug('Deployments:List <all_environments: {0}>'
+                  .format(all_environments))
+
+        if all_environments:
+            policy.check("list_deployments_all_environments", request.context)
+        else:
+            check_env(request, environment_id)
+            target = {"environment_id": environment_id}
+            policy.check("list_deployments", request.context, target)
 
         unit = db_session.get_session()
-        query = unit.query(models.Task) \
-            .filter_by(environment_id=environment_id) \
-            .order_by(desc(models.Task.created))
-        result = query.all()
-        deployments = [set_dep_state(deployment, unit).to_dict() for deployment
-                       in result]
+
+        if all_environments:
+            query = unit.query(models.Environment) \
+                .options(load_only('tenant_id')) \
+                .filter_by(tenant_id=request.context.tenant) \
+                .join(models.Task) \
+                .order_by(desc(models.Task.created))
+            result = query.all()
+            # The join statement above fetches the deployments into
+            # Environment.tasks. Iterate over that to get the deployments.
+            deployments = []
+            for row in result:
+                for deployment in row.tasks:
+                    deployment = set_dep_state(deployment, unit).to_dict()
+                    deployments.append(deployment)
+        else:
+            query = unit.query(models.Task) \
+                .filter_by(environment_id=environment_id) \
+                .order_by(desc(models.Task.created))
+            result = query.all()
+            deployments = [set_dep_state(deployment, unit).to_dict()
+                           for deployment in result]
         return {'deployments': deployments}
 
     @request_statistics.stats_count(API_NAME, 'Statuses')
@@ -87,13 +110,13 @@ def _patch_description(description):
 def verify_and_get_deployment(db_session, environment_id, deployment_id):
     deployment = db_session.query(models.Task).get(deployment_id)
     if not deployment:
-        LOG.error(_LE('Deployment with id {id} not found')
+        LOG.error('Deployment with id {id} not found'
                   .format(id=deployment_id))
         raise exc.HTTPNotFound
     if deployment.environment_id != environment_id:
-        LOG.error(_LE('Deployment with id {d_id} not found in environment '
-                      '{env_id}').format(d_id=deployment_id,
-                                         env_id=environment_id))
+        LOG.error('Deployment with id {d_id} not found in environment '
+                  '{env_id}'.format(d_id=deployment_id,
+                                    env_id=environment_id))
         raise exc.HTTPBadRequest
 
     deployment.description = _patch_description(deployment.description)
