@@ -18,7 +18,7 @@ import six
 from webob import exc
 
 from murano.api.v1 import request_statistics
-from murano.common.i18n import _, _LE
+from murano.common.i18n import _
 from murano.common import policy
 from murano.common import utils
 from murano.common import wsgi
@@ -230,14 +230,14 @@ class Controller(object):
         :return: the description of the created template.
         """
 
-        LOG.debug('EnvTemplates:Clone <Env Template {0} for body {1}>'.
+        LOG.debug('EnvTemplates:Clone <Env Template {1} for body {0}>'.
                   format(body, env_template_id))
         policy.check('clone_env_template', request.context)
 
         old_env_template = self._validate_exists(env_template_id)
 
         if not old_env_template.get('is_public'):
-            msg = _LE('User has no access to these resources.')
+            msg = _('User has no access to these resources.')
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
         self._validate_body_name(body)
@@ -256,13 +256,11 @@ class Controller(object):
         return template.to_dict()
 
     def _validate_request(self, request, env_template_id):
-        self._validate_exists(env_template_id)
-        get_env_template = env_temps.EnvTemplateServices.get_env_template
-        env_template = get_env_template(env_template_id)
+        env_template = self._validate_exists(env_template_id)
         if env_template.is_public or request.context.is_admin:
             return
         if env_template.tenant_id != request.context.tenant:
-            msg = _LE('User has no access to these resources.')
+            msg = _('User has no access to these resources.')
             LOG.error(msg)
             raise exc.HTTPForbidden(explanation=msg)
 
