@@ -50,11 +50,12 @@ def main():
         config.parse_args()
 
         logging.setup(CONF, 'murano')
-        workers = CONF.engine.workers
+        workers = CONF.engine.engine_workers
         if not workers:
             workers = processutils.get_worker_count()
-        launcher = service.launch(CONF,
-                                  engine.EngineService(), workers=workers)
+        launcher = service.launch(
+            CONF, engine.EngineService(),
+            workers=workers, restart_method='mutate')
         launcher.wait()
     except RuntimeError as e:
         sys.stderr.write("ERROR: %s\n" % e)
