@@ -23,19 +23,20 @@ from muranoclient.common import utils
 from oslo_config import cfg
 from oslo_db import options
 from oslo_log import log as logging
-from oslo_utils import importutils
-import six
+from oslo_utils import timeutils
 
-from murano import version
-from murano.common.i18n import _, _LE
 from murano.common import config
 from murano.common import engine
+from murano.common.i18n import _
+from murano.dsl import dsl_exception
+from murano.dsl import dsl_types
 from murano.dsl import exceptions
 from murano.dsl import executor
 from murano.dsl import helpers
 from murano.engine import execution_session
 from murano.engine import mock_context_manager
 from murano.engine import package_loader
+from murano import version
 
 
 CONF = cfg.CONF
@@ -45,6 +46,11 @@ options.set_defaults(CONF)
 BASE_CLASS = 'io.murano.test.TestFixture'
 TEST_CASE_NAME = re.compile('^test(?![a-z])')
 
+OK_COLOR = '\033[92m'
+FAIL_COLOR = '\033[91m'
+END_COLOR = '\033[0m'
+
+
 if os.name == 'nt':
     # eventlet monkey patching causes subprocess.Popen to fail on Windows
     # when using pipes due to missing non blocking I/O support
@@ -99,7 +105,7 @@ class MuranoTestRunner(object):
             # Check for method name occurrence in all methods.
             # if there is no dot in provided item - it is a method name
             if '.' not in item:
-                for class_name, methods in six.iteritems(class_to_methods):
+                for class_name, methods in class_to_methods.items():
                     methods_to_run[class_name] = []
                     if item in methods:
                         methods_to_run[class_name].append(item)
@@ -118,9 +124,9 @@ class MuranoTestRunner(object):
                     m for m in class_to_methods[class_to_test]
                     if m == test_method]
                 continue
-        methods_count = sum(len(v) for v in six.itervalues(methods_to_run))
+        methods_count = sum(len(v) for v in methods_to_run.values())
         methods = [k + '.' + method
-                   for k, v in six.iteritems(methods_to_run) for method in v]
+                   for k, v in methods_to_run.items() for method in v]
         LOG.debug('{0} method(s) is(are) going to be executed: '
                   '\n{1}'.format(methods_count, '\n'.join(methods)))
         return methods_to_run
@@ -151,17 +157,18 @@ class MuranoTestRunner(object):
         return class_to_methods
 
     def _call_service_method(self, name, exc, obj):
-        if name in obj.type.methods:
-            obj.type.methods[name].usage = 'Action'
+        if name in obj.type.all_method_names:
+            method = obj.type.find_single_method(name)
+            method.scope = dsl_types.MethodScopes.Public
             LOG.debug('Executing: {0}.{1}'.format(obj.type.name, name))
-            obj.type.invoke(name, exc, obj, (), {})
+            exc.run(obj.type, name, obj, (), {})
 
     def _validate_keystone_opts(self, args):
         ks_opts_to_config = {
-            'auth_url': 'auth_uri',
+            'auth_url': 'www_authenticate_uri',
             'username': 'admin_user',
             'password': 'admin_password',
-            'project_name': 'admin_tenant_name'}
+            'project_name': 'admin_project_name'}
 
         ks_opts = {'auth_url': getattr(args, 'os_auth_url', None),
                    'username': getattr(args, 'os_username', None),
@@ -169,18 +176,16 @@ class MuranoTestRunner(object):
                    'project_name': getattr(args, 'os_project_name', None)}
 
         if None in ks_opts.values() and not CONF.default_config_files:
-            msg = _LE('Please provide murano config file or credentials for '
-                      'authorization: {0}').format(
+            msg = ('Please provide murano config file or credentials for '
+                   'authorization: {0}').format(
                 ', '.join(['--os-auth-url', '--os-username', '--os-password',
                            '--os-project-name', '--os-tenant-id']))
             LOG.error(msg)
             self.error(msg)
-        # Load keystone configuration parameters from config
-        importutils.import_module('keystonemiddleware.auth_token')
 
-        for param, value in six.iteritems(ks_opts):
+        for param, value in ks_opts.items():
             if not value:
-                ks_opts[param] = getattr(CONF.keystone_authtoken,
+                ks_opts[param] = getattr(CONF.murano_auth,
                                          ks_opts_to_config[param])
             if param == 'auth_url':
                 ks_opts[param] = ks_opts[param].replace('v2.0', 'v3')
@@ -192,6 +197,9 @@ class MuranoTestRunner(object):
             self.parser.print_help()
         sys.exit(1)
 
+    def message(self, msg):
+        sys.stdout.write('{0}\n'.format(msg))
+
     def run_tests(self):
         exit_code = 0
         provided_pkg_name = self.args.package
@@ -216,14 +224,26 @@ class MuranoTestRunner(object):
             run_set = self._get_methods_to_run(package,
                                                tests_to_run,
                                                class_to_methods)
+            max_length = 0
+            num_tests = 0
+            for pkg_class, test_cases in run_set.items():
+                for m in test_cases:
+                    max_length = max(max_length, len(pkg_class)+len(m)+1)
+                num_tests += len(test_cases)
+            max_length += 3
+
             if run_set:
                 LOG.debug('Starting test execution.')
+                self.message('About to execute {0} tests(s)'.format(num_tests))
             else:
                 msg = _('No tests found for execution.')
                 LOG.error(msg)
                 self.error(msg)
 
-            for pkg_class, test_cases in six.iteritems(run_set):
+            run_count = 0
+            error_count = 0
+            started = timeutils.utcnow()
+            for pkg_class, test_cases in run_set.items():
                 for m in test_cases:
                     # Create new executor for each test case to provide
                     # pure test environment
@@ -231,24 +251,57 @@ class MuranoTestRunner(object):
                         pkg_loader,
                         mock_context_manager.MockContextManager(),
                         test_session)
-                    obj = package.find_class(pkg_class, False).new(
-                        None, dsl_executor.object_store, dsl_executor)(None)
+                    obj = dsl_executor.object_store.load(
+                        {}, None,
+                        default_type=package.find_class(pkg_class, False))
+
+                    test_name = "{0}.{1}".format(obj.type.name, m)
+                    dots_number = max_length - len(test_name)
+                    msg = "{0} {1} ".format(test_name, '.' * dots_number)
+                    sys.stdout.write(msg)
+                    sys.stdout.flush()
                     self._call_service_method('setUp', dsl_executor, obj)
                     obj.type.methods[m].usage = 'Action'
-
                     test_session.start()
                     try:
-                        obj.type.invoke(m, dsl_executor, obj, (), {})
-                        LOG.debug('\n.....{0}.{1}.....OK'.format(obj.type.name,
-                                                                 m))
+                        run_count += 1
+                        dsl_executor.run(obj.type, m, obj, (), {})
                         self._call_service_method(
                             'tearDown', dsl_executor, obj)
-                    except Exception:
-                        LOG.exception('\n.....{0}.{1}.....FAILURE\n'
-                                      ''.format(obj.type.name, m))
+                        msg = '{0}{1}{2}\n'.format(OK_COLOR, 'OK', END_COLOR)
+                        LOG.debug('Test {0} successful'.format(test_name))
+                        sys.stdout.write(msg)
+                        sys.stdout.flush()
+                    except Exception as e:
+                        error_count += 1
+                        msg = ''.join((
+                            FAIL_COLOR, 'FAIL!', END_COLOR, '\n'))
+                        sys.stdout.write(msg)
+                        if isinstance(e, dsl_exception.MuranoPlException):
+                            tb = e.format()
+                        else:
+                            tb = traceback.format_exc()
+
+                        sys.stdout.write(''.join((
+                            FAIL_COLOR,
+                            tb,
+                            END_COLOR,
+                            '\n'
+                        )))
+                        sys.stdout.flush()
+
+                        LOG.exception('Test {0} failed'.format(test_name))
                         exit_code = 1
                     finally:
                         test_session.finish()
+            completed = timeutils.utcnow()
+            self.message('Executed {0} tests in {1} seconds: '
+                         '{2} passed, '
+                         '{3} failed'.format(run_count,
+                                             timeutils.delta_seconds(
+                                                 started, completed),
+                                             run_count-error_count,
+                                             error_count))
         return exit_code
 
     def get_parser(self):
@@ -307,17 +360,21 @@ def main():
                     default_config_files = [murano_conf]
         sys.argv = [sys.argv[0]]
         config.parse_args(default_config_files=default_config_files)
+        CONF.set_default('use_stderr', False)
         logging.setup(CONF, 'murano')
     except RuntimeError as e:
-        LOG.exception(_LE("Failed to initialize murano-test-runner: %s") % e)
+        LOG.exception("Failed to initialize murano-test-runner: %s", e)
         sys.exit("ERROR: %s" % e)
 
     try:
         exit_code = test_runner.run_tests()
         sys.exit(exit_code)
     except Exception as e:
-        tb = traceback.format_exc()
-        err_msg = _LE("Command failed: {0}\n{1}").format(e, tb)
+        if isinstance(e, dsl_exception.MuranoPlException):
+            tb = e.format()
+        else:
+            tb = traceback.format_exc()
+        err_msg = "Command failed: {0}\n{1}".format(e, tb)
         LOG.error(err_msg)
         sys.exit(err_msg)
 
