@@ -21,6 +21,7 @@ import eventlet.debug
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
+from oslo_messaging.rpc import dispatcher
 from oslo_messaging import target
 from oslo_serialization import jsonutils
 from oslo_service import service
@@ -39,7 +40,6 @@ from murano.engine import execution_session
 from murano.engine import package_loader
 from murano.engine.system import status_reporter
 from murano.engine.system import yaql_functions
-from murano.common.i18n import _LI, _LE, _LW
 from murano.policy import model_policy_enforcer as enforcer
 
 CONF = cfg.CONF
@@ -64,10 +64,12 @@ class EngineService(service.Service):
             SchemaEndpoint()
         ]
 
-        transport = messaging.get_transport(CONF)
+        transport = messaging.get_notification_transport(CONF)
         s_target = target.Target('murano', 'tasks', server=str(uuid.uuid4()))
+        access_policy = dispatcher.DefaultRPCAccessPolicy
         self.server = messaging.get_rpc_server(
-            transport, s_target, endpoints, 'eventlet')
+            transport, s_target, endpoints, 'eventlet',
+            access_policy=access_policy)
         self.server.start()
         super(EngineService, self).start()
 
@@ -128,7 +130,7 @@ class TaskProcessingEndpoint(object):
     @staticmethod
     def execute(task):
         s_task = token_sanitizer.TokenSanitizer().sanitize(task)
-        LOG.info(_LI('Starting processing task: {task_desc}').format(
+        LOG.info('Starting processing task: {task_desc}'.format(
             task_desc=jsonutils.dumps(s_task)))
 
         result = None
@@ -139,16 +141,17 @@ class TaskProcessingEndpoint(object):
             result = task_executor.execute()
             return result
         finally:
-            LOG.info(_LI('Finished processing task: {task_desc}').format(
-                task_desc=jsonutils.dumps(result)))
+            s_result = token_sanitizer.TokenSanitizer().sanitize(result)
+            LOG.info('Finished processing task: {task_desc}'.format(
+                task_desc=jsonutils.dumps(s_result)))
 
 
 class StaticActionEndpoint(object):
     @classmethod
     def call_static_action(cls, context, task):
         s_task = token_sanitizer.TokenSanitizer().sanitize(task)
-        LOG.info(_LI('Starting execution of static action: '
-                     '{task_desc}').format(task_desc=jsonutils.dumps(s_task)))
+        LOG.info('Starting execution of static action: '
+                 '{task_desc}'.format(task_desc=jsonutils.dumps(s_task)))
 
         result = None
         reporter = status_reporter.StatusReporter(task['id'])
@@ -158,8 +161,8 @@ class StaticActionEndpoint(object):
             result = task_executor.execute()
             return result
         finally:
-            LOG.info(_LI('Finished execution of static action: '
-                     '{task_desc}').format(task_desc=jsonutils.dumps(result)))
+            LOG.info('Finished execution of static action: '
+                     '{task_desc}'.format(task_desc=jsonutils.dumps(result)))
 
 
 class TaskExecutor(object):
@@ -182,7 +185,10 @@ class TaskExecutor(object):
         self._model = task['model']
         self._session = execution_session.ExecutionSession()
         self._session.token = task['token']
-        self._session.project_id = task['tenant_id']
+        self._session.project_id = task['project_id']
+        self._session.user_id = task['user_id']
+        self._session.environment_owner_project_id = self._model['project_id']
+        self._session.environment_owner_user_id = self._model['user_id']
         self._session.system_attributes = self._model.get('SystemData', {})
         self._reporter = reporter
 
@@ -202,6 +208,8 @@ class TaskExecutor(object):
             self._session.system_attributes[
                 'Packages'] = pkg_loader.export_fixation_table()
         self._model['SystemData'] = self._session.system_attributes
+        self._model['project_id'] = self._session.environment_owner_project_id
+        self._model['user_id'] = self._session.environment_owner_user_id
         result['model'] = self._model
 
         if (not self._model.get('Objects') and
@@ -209,7 +217,7 @@ class TaskExecutor(object):
             try:
                 self._delete_trust()
             except Exception:
-                LOG.warning(_LW('Cannot delete trust'), exc_info=True)
+                LOG.warning('Cannot delete trust', exc_info=True)
 
         return result
 
@@ -272,8 +280,8 @@ class TaskExecutor(object):
         else:
             exception_traceback = traceback.format_exc()
             LOG.exception(
-                _LE("Exception %(exc)s occurred"
-                    " during invocation of %(method)s"),
+                ("Exception %(exc)s occurred"
+                 " during invocation of %(method)s"),
                 {'exc': exception, 'method': method_name})
         self._reporter.report_error(root, str(exception))
 
@@ -335,7 +343,8 @@ class StaticActionExecutor(object):
         self._action = task['action']
         self._session = execution_session.ExecutionSession()
         self._session.token = task['token']
-        self._session.project_id = task['tenant_id']
+        self._session.project_id = task['project_id']
+        self._session.user_id = task['user_id']
         self._reporter = reporter
         self._model_policy_enforcer = enforcer.ModelPolicyEnforcer(
             self._session)
