@@ -17,7 +17,6 @@ SQLAlchemy models for murano data
 """
 from oslo_db.sqlalchemy import models
 from oslo_utils import timeutils
-import six
 import sqlalchemy as sa
 from sqlalchemy.ext import declarative
 from sqlalchemy import orm as sa_orm
@@ -47,7 +46,7 @@ class TimestampMixin(object):
 class _MuranoBase(models.ModelBase):
     def to_dict(self):
         dictionary = self.__dict__.copy()
-        return dict((k, v) for k, v in six.iteritems(dictionary)
+        return dict((k, v) for k, v in dictionary.items()
                     if k != '_sa_instance_state')
 
 
@@ -55,7 +54,7 @@ Base = declarative.declarative_base(cls=_MuranoBase)
 
 
 class Environment(Base, TimestampMixin):
-    """Represents a Environment in the metadata-store."""
+    """Represents an Environment in the metadata-store."""
     __tablename__ = 'environment'
     __table_args__ = (sa.Index(
         'ix_name_tenant_id', 'name', 'tenant_id', unique=True),)
@@ -65,6 +64,7 @@ class Environment(Base, TimestampMixin):
                    default=uuidutils.generate_uuid)
     name = sa.Column(sa.String(255), nullable=False)
     tenant_id = sa.Column(sa.String(36), nullable=False)
+    description_text = sa.Column(sa.String(), nullable=False, default='')
     version = sa.Column(sa.BigInteger, nullable=False, default=0)
     description = sa.Column(st.JsonBlob(), nullable=False, default={})
 
@@ -88,7 +88,7 @@ class Environment(Base, TimestampMixin):
 
 
 class EnvironmentTemplate(Base, TimestampMixin):
-    """Represents a Environment Template in the metadata-store."""
+    """Represents an Environment Template in the metadata-store."""
     __tablename__ = 'environment-template'
 
     id = sa.Column(sa.String(36),
@@ -96,6 +96,7 @@ class EnvironmentTemplate(Base, TimestampMixin):
                    default=uuidutils.generate_uuid)
     name = sa.Column(sa.String(255), nullable=False)
     tenant_id = sa.Column(sa.String(36), nullable=False)
+    description_text = sa.Column(sa.String(), nullable=False, default='')
     version = sa.Column(sa.BigInteger, nullable=False, default=0)
     description = sa.Column(st.JsonBlob(), nullable=False, default={})
     is_public = sa.Column(sa.Boolean, default=False)
@@ -355,7 +356,7 @@ class CFServiceInstance(Base):
     tenant = sa.Column(sa.String(255), nullable=False)
 
     def to_dict(self):
-        dictionary = super(CFSpace, self).to_dict()
+        dictionary = super(CFServiceInstance, self).to_dict()
         if 'environment' in dictionary:
             del dictionary['environment']
         return dictionary
