@@ -26,6 +26,7 @@ import weakref
 
 import eventlet.greenpool
 import eventlet.greenthread
+from oslo_config import cfg
 import semantic_version
 import six
 from yaql.language import contexts
@@ -41,6 +42,7 @@ from murano.dsl import exceptions
 _threads_sequencer = 0
 # type string: ns.something.MyApp[/1.2.3-alpha][@my.package.fqn]
 TYPE_RE = re.compile(r'([a-zA-Z0-9_.]+)(?:/([^@]+))?(?:@([a-zA-Z0-9_.]+))?$')
+CONF = cfg.CONF
 
 
 def evaluate(value, context, freeze=True):
@@ -55,7 +57,7 @@ def evaluate(value, context, freeze=True):
         return dict_type(
             (evaluate(d_key, context, freeze),
              evaluate(d_value, context, freeze))
-            for d_key, d_value in six.iteritems(value))
+            for d_key, d_value in value.items())
     elif yaqlutils.is_sequence(value):
         return list_type(evaluate(t, context, freeze) for t in value)
     elif isinstance(value, yaqlutils.SetType):
@@ -64,7 +66,7 @@ def evaluate(value, context, freeze=True):
         return list_type(
             evaluate(t, context, freeze)
             for t in yaqlutils.limit_iterable(
-                value, constants.ITERATORS_LIMIT))
+                value, CONF.murano.dsl_iterators_limit))
     elif isinstance(value, dsl_types.MuranoObjectInterface):
         return value.object
     else:
@@ -130,7 +132,7 @@ def parallel_select(collection, func, limit=1000):
     except StopIteration:
         return map(lambda t: t[0], result)
     else:
-        six.reraise(exception[0], None, exception[2])
+        six.reraise(type(exception[0]), exception[0], exception[2])
 
 
 def enum(**enums):
@@ -570,10 +572,11 @@ def parse_object_definition(spec, scope_type, context):
         'properties': yaqlutils.filter_parameters_dict(props),
         'id': system_data.get('id'),
         'name': system_data.get('name'),
+        'metadata': system_data.get('metadata'),
         'destroyed': system_data.get('destroyed', False),
         'dependencies': system_data.get('dependencies', {}),
         'extra': {
-            key: value for key, value in six.iteritems(system_data)
+            key: value for key, value in system_data.items()
             if key.startswith('_')
         }
     }
@@ -585,6 +588,7 @@ def assemble_object_definition(parsed, model_format=dsl_types.DumpTypes.Mixed):
             parsed['type']: parsed['properties'],
             'id': parsed['id'],
             'name': parsed['name'],
+            'metadata': parsed['metadata'],
             'dependencies': parsed['dependencies'],
             'destroyed': parsed['destroyed']
         }
@@ -593,7 +597,8 @@ def assemble_object_definition(parsed, model_format=dsl_types.DumpTypes.Mixed):
     result = parsed['properties']
     header = {
         'id': parsed['id'],
-        'name': parsed['name']
+        'name': parsed['name'],
+        'metadata': parsed['metadata']
     }
     if parsed['destroyed']:
         header['destroyed'] = True
