@@ -21,10 +21,9 @@ import heatclient.client as hclient
 import heatclient.exc as heat_exc
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
 from murano.common import auth_utils
-from murano.common.i18n import _LW
+from murano.common.helpers import token_sanitizer
 from murano.dsl import dsl
 from murano.dsl import helpers
 from murano.dsl import session_local_storage
@@ -46,18 +45,32 @@ class HeatStack(object):
         self._template = None
         self._parameters = {}
         self._files = {}
-        self._hot_environment = ''
+        self._hot_environment = {}
         self._applied = True
         self._description = description
         self._last_stack_timestamps = (None, None)
         self._tags = ''
         self._region_name = region_name
+        self._push_thread = None
+
+    def _is_push_thread_alive(self):
+        return self._push_thread is not None and not self._push_thread.dead
+
+    def _kill_push_thread(self):
+        if self._is_push_thread_alive():
+            self._push_thread.cancel()
+            self._wait_push_thread()
+
+    def _wait_push_thread(self):
+        if not self._is_push_thread_alive():
+            return
+        self._push_thread.wait()
 
     @staticmethod
     def _create_client(session, region_name):
         parameters = auth_utils.get_session_client_parameters(
             service_type='orchestration', region=region_name,
-            conf=CONF.heat, session=session)
+            conf='heat', session=session)
         return hclient.Client('1', **parameters)
 
     @property
@@ -67,11 +80,11 @@ class HeatStack(object):
     @staticmethod
     @session_local_storage.execution_session_memoize
     def _get_client(region_name):
-        session = auth_utils.get_client_session(conf=CONF.heat)
+        session = auth_utils.get_client_session(conf='heat')
         return HeatStack._create_client(session, region_name)
 
     def _get_token_client(self):
-        ks_session = auth_utils.get_token_client_session(conf=CONF.heat)
+        ks_session = auth_utils.get_token_client_session(conf='heat')
         return self._create_client(ks_session, self._region_name)
 
     def current(self):
@@ -133,7 +146,7 @@ class HeatStack(object):
 
     @staticmethod
     def _remove_system_params(parameters):
-        return dict((k, v) for k, v in six.iteritems(parameters) if
+        return dict((k, v) for k, v in parameters.items() if
                     not k.startswith('OS::'))
 
     def _get_status(self):
@@ -142,14 +155,12 @@ class HeatStack(object):
         def status_func(state_value):
             status[0] = state_value
             return True
-
         self._wait_state(status_func)
         return status[0]
 
     def _wait_state(self, status_func, wait_progress=False):
         tries = 4
         delay = 1
-
         while tries > 0:
             while True:
                 try:
@@ -197,9 +208,59 @@ class HeatStack(object):
         return {}
 
     def output(self):
+        self._wait_push_thread()
         return self._wait_state(lambda status: True)
 
-    def push(self):
+    def _push(self, object_store=None):
+        template = copy.deepcopy(self._template)
+        s_template = token_sanitizer.TokenSanitizer().sanitize(template)
+        LOG.debug('Pushing: {template}'.format(
+            template=json.dumps(s_template)))
+        object_store = object_store or helpers.get_object_store()
+        while True:
+            try:
+                with helpers.with_object_store(object_store):
+                    current_status = self._get_status()
+                    resources = template.get('Resources') or template.get(
+                        'resources')
+                    if current_status == 'NOT_FOUND':
+                        if resources is not None:
+                            token_client = self._get_token_client()
+                            token_client.stacks.create(
+                                stack_name=self._name,
+                                parameters=self._parameters,
+                                template=template,
+                                files=self._files,
+                                environment=self._hot_environment,
+                                disable_rollback=True,
+                                tags=self._tags)
+
+                            self._wait_state(
+                                lambda status: status == 'CREATE_COMPLETE')
+                    else:
+                        if resources is not None:
+                            self._client.stacks.update(
+                                stack_id=self._name,
+                                parameters=self._parameters,
+                                files=self._files,
+                                environment=self._hot_environment,
+                                template=template,
+                                disable_rollback=True,
+                                tags=self._tags)
+                            self._wait_state(
+                                lambda status: status == 'UPDATE_COMPLETE',
+                                True)
+                        else:
+                            self.delete()
+            except heat_exc.HTTPConflict as e:
+                LOG.warning('Conflicting operation: {msg}'.format(msg=e))
+                eventlet.sleep(3)
+            else:
+                break
+
+        self._applied = self._template == template
+
+    def push(self, async=False):
         if self._applied or self._template is None:
             return
 
@@ -210,51 +271,26 @@ class HeatStack(object):
         if 'description' not in self._template and self._description:
             self._template['description'] = self._description
 
-        template = copy.deepcopy(self._template)
-        LOG.debug('Pushing: {template}'.format(template=json.dumps(template)))
+        self._kill_push_thread()
+        if async:
+            if self._push_thread is None:
 
-        while True:
-            try:
-                current_status = self._get_status()
-                resources = template.get('Resources') or template.get(
-                    'resources')
-                if current_status == 'NOT_FOUND':
-                    if resources is not None:
-                        token_client = self._get_token_client()
-                        token_client.stacks.create(
-                            stack_name=self._name,
-                            parameters=self._parameters,
-                            template=template,
-                            files=self._files,
-                            environment=self._hot_environment,
-                            disable_rollback=True,
-                            tags=self._tags)
+                def cleanup():
+                    try:
+                        self._wait_push_thread()
+                    finally:
+                        self._push_thread = None
 
-                        self._wait_state(
-                            lambda status: status == 'CREATE_COMPLETE')
-                else:
-                    if resources is not None:
-                        self._client.stacks.update(
-                            stack_id=self._name,
-                            parameters=self._parameters,
-                            files=self._files,
-                            environment=self._hot_environment,
-                            template=template,
-                            disable_rollback=True,
-                            tags=self._tags)
-                        self._wait_state(
-                            lambda status: status == 'UPDATE_COMPLETE', True)
-                    else:
-                        self.delete()
-            except heat_exc.HTTPConflict as e:
-                LOG.warning(_LW('Conflicting operation: {msg}').format(msg=e))
-                eventlet.sleep(3)
-            else:
-                break
+                dsl.get_execution_session().on_session_finish(cleanup)
 
-        self._applied = self._template == template
+            self._push_thread =\
+                eventlet.greenthread.spawn_after(
+                    1, self._push, helpers.get_object_store())
+        else:
+            self._push()
 
     def delete(self):
+        self._kill_push_thread()
         while True:
             try:
                 if not self.current():
@@ -265,11 +301,11 @@ class HeatStack(object):
                     lambda status: status in ('DELETE_COMPLETE', 'NOT_FOUND'),
                     wait_progress=True)
             except heat_exc.NotFound:
-                LOG.warning(_LW('Stack {stack_name} already deleted?')
+                LOG.warning('Stack {stack_name} already deleted?'
                             .format(stack_name=self._name))
                 break
             except heat_exc.HTTPConflict as e:
-                LOG.warning(_LW('Conflicting operation: {msg}').format(msg=e))
+                LOG.warning('Conflicting operation: {msg}'.format(msg=e))
                 eventlet.sleep(3)
             else:
                 break
