@@ -19,6 +19,7 @@ import sys
 import six
 import yaml
 
+from murano.common.helpers import path
 from murano.packages import exceptions
 from murano.packages import package_base
 
@@ -76,12 +77,14 @@ class HotPackage(package_base.PackageBase):
         return self._translated_class, '<generated code>'
 
     def _translate_class(self):
-        template_file = os.path.join(self._source_directory, 'template.yaml')
-        shutil.copy(template_file, self.get_resource(self.full_name))
+        template_file = path.secure_join(
+            self._source_directory, 'template.yaml')
 
         if not os.path.isfile(template_file):
             raise exceptions.PackageClassLoadError(
                 self.full_name, 'File with class definition not found')
+
+        shutil.copy(template_file, self.get_resource(self.full_name))
         with open(template_file) as stream:
             hot = yaml.safe_load(stream)
             if 'resources' not in hot:
@@ -91,9 +94,8 @@ class HotPackage(package_base.PackageBase):
             'Extends': 'io.murano.Application'
         }
 
-        hot_envs_path = os.path.join(self._source_directory,
-                                     RESOURCES_DIR_NAME,
-                                     HOT_ENV_DIR_NAME)
+        hot_envs_path = path.secure_join(
+            self._source_directory, RESOURCES_DIR_NAME, HOT_ENV_DIR_NAME)
 
         # if using hot environments, doing parameter validation with contracts
         # will overwrite the parameters in the hot environment.
@@ -177,7 +179,7 @@ class HotPackage(package_base.PackageBase):
     @staticmethod
     def _translate_outputs(hot):
         contract = {}
-        for key in six.iterkeys(hot.get('outputs') or {}):
+        for key in (hot.get('outputs') or {}).keys():
             contract[key] = YAQL("$.string()")
         return {
             'templateOutputs': {
@@ -189,9 +191,8 @@ class HotPackage(package_base.PackageBase):
 
     @staticmethod
     def _translate_files(source_directory):
-        hot_files_path = os.path.join(source_directory,
-                                      RESOURCES_DIR_NAME,
-                                      HOT_FILES_DIR_NAME)
+        hot_files_path = path.secure_join(
+            source_directory, RESOURCES_DIR_NAME, HOT_FILES_DIR_NAME)
 
         return HotPackage._build_hot_resources(hot_files_path)
 
@@ -201,7 +202,7 @@ class HotPackage(package_base.PackageBase):
         if os.path.isdir(basedir):
             for root, _, files in os.walk(os.path.abspath(basedir)):
                 for f in files:
-                    full_path = os.path.join(root, f)
+                    full_path = path.secure_join(root, f)
                     relative_path = os.path.relpath(full_path, basedir)
                     result.append(relative_path)
         return result
@@ -390,7 +391,7 @@ class HotPackage(package_base.PackageBase):
 
         rest_group = []
         properties = []
-        for key, value in six.iteritems(hot_parameters):
+        for key, value in hot_parameters.items():
             if key not in used_parameters:
                 rest_group.append(HotPackage._translate_ui_parameter(
                     key, value))
@@ -439,11 +440,11 @@ class HotPackage(package_base.PackageBase):
                 spec = constraint['length']
                 if 'min' in spec:
                     translated['minLength'] = max(
-                        translated.get('minLength', -sys.maxint - 1),
+                        translated.get('minLength', -sys.maxsize - 1),
                         int(spec['min']))
                 if 'max' in spec:
                     translated['maxLength'] = min(
-                        translated.get('maxLength', sys.maxint),
+                        translated.get('maxLength', sys.maxsize),
                         int(spec['max']))
 
             elif 'range' in constraint:
@@ -516,7 +517,8 @@ class HotPackage(package_base.PackageBase):
         return app
 
     def _translate_ui(self):
-        template_file = os.path.join(self._source_directory, 'template.yaml')
+        template_file = path.secure_join(
+            self._source_directory, 'template.yaml')
 
         if not os.path.isfile(template_file):
             raise exceptions.PackageClassLoadError(
